# 贡献，并且帮助我们改进

感谢您参与本项目，对于任何形式的贡献我们都欢迎；

目前我们欢迎以下方面的贡献：

## 帮助改进 YouQu 文档

欢迎任何微如错别字、大到添加章节帮助我们提高项目的 Pull Requests。

## 向 YouQu 提交 Issues

Issues 提交地址：https://github.com/linuxdeepin/youqu/issues

## 向 YouQu 仓库提交代码

底层基础能力的代码为上层业务服务，不应该把含有业务相关的代码提交到框架底层；
